import hashlib

GRAVATAR_URL = 'http://www.gravatar.com/avatar/'

class Gravtr(object):
    def __init__(self, email):
        self.email = email

    def generate(self, size=None):
        email = self.email.encode('utf-8')
        self.url = GRAVATAR_URL + hashlib.md5(email).hexdigest()
        if size:
            self.url = self.url + '?' + 's={}'.format(str(size))
        return self.url



from setuptools import setup

setup(
    name="gravtr",
    version="0.0.3",

    description="Simple gravatar url generator",

    # The project URL.
    url='https://github.com/gfabricio/gravtr',

    # Author details
    author='Guilherme Fabricio',
    author_email='gfabricio@gmail.com',

    # Choose your license
    license='MIT',

    use_2to3=True,

    classifiers=[
        'Development Status :: 3 - Alpha',

        # Who the project is intended for.
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: User Interfaces',
        'Topic :: Utilities',

        'License :: OSI Approved :: MIT License',

    ],
    keywords='gravatar avatar gravtr',
    packages=['gravtr'],
)
